pub fn write_repeater_list(entries: &[RepeaterEntry]) -> Vec<u8> ⓘExpand description
Generates a repeater list TSV file as UTF-16LE bytes with BOM.
The output includes a header row followed by one row per entry.
pub fn write_repeater_list(entries: &[RepeaterEntry]) -> Vec<u8> ⓘGenerates a repeater list TSV file as UTF-16LE bytes with BOM.
The output includes a header row followed by one row per entry.